import { useContext } from 'react';
import {
  NodeAttribute,
  SchemaReactflowEntityNode,
  SchemaReactflowRelationNode,
  handleDataFromReactflowToDataId,
  toHandleId,
} from '../../model';
import { Handle, Position } from 'reactflow';
import { PillHandle } from '@graphpolaris/shared/lib/components/pills/PillHandle';
import { pillDropdownPadding } from '@graphpolaris/shared/lib/components/pills/pill.const';
import { Button } from '../../..';
import { QueryBuilderDispatcherContext } from '../../panel/QueryBuilderDispatcher';

type PillDropdownItemProps = {
  attribute: NodeAttribute;
  node: SchemaReactflowEntityNode | SchemaReactflowRelationNode;
  className?: string;
  mr?: number;
  icon: string | undefined;
};

export const PillDropdownItem = (props: PillDropdownItemProps) => {
  const { openLogicPillCreate } = useContext(QueryBuilderDispatcherContext);

  if (props.attribute.handleData.attributeName === undefined) {
    throw new Error('attribute.handleData.attributeName is undefined');
  }

  const handleId = toHandleId(handleDataFromReactflowToDataId(props.node, props.attribute));
  const handleType = 'source';

  return (
    <div className="px-2 py-1 bg-secondary-100 flex justify-between items-center">
      <p className="truncate text-[0.6rem]">{props.attribute.handleData.attributeName}</p>
      <Button
        variantType="secondary"
        variant="ghost"
        size="2xs"
        iconComponent={props.icon}
        onClick={() => {
          openLogicPillCreate(
            {
              nodeId: props.node.id,
              handleId: handleId,
              handleType: handleType,
            },
            {
              x: props.node.xPos + 200,
              y: props.node.yPos + 50,
            },
          );
        }}
      />
      <PillHandle
        mr={-pillDropdownPadding + (props.mr || 0)}
        handleTop="auto"
        position={Position.Right}
        className={`stroke-white${props.className ? ` ${props.className}` : ''}`}
        type="square"
      >
        <Handle
          id={handleId}
          type={handleType}
          position={Position.Right}
          className={'!rounded-none !bg-transparent !w-full !h-full !right-0 !left-0 !border-0'}
        ></Handle>
      </PillHandle>
    </div>
  );
};
